@@ -29,7 +29,7 @@ from pythonvideoannotator_models.utils.tools import points_angle, rotate_image
 class ContoursImagesWindow(BaseWidget):
 
     def __init__(self, parent=None):
-        super(ContoursImagesWindow, self).__init__('Contours images', parent_win=parent)
+        super(ContoursImagesWindow, self).__init__('Contour images', parent_win=parent)
         self.mainwindow = parent
 
         self.set_margin(5)
@@ -42,7 +42,7 @@ class ContoursImagesWindow(BaseWidget):
         self._progress      = ControlProgress('Progress', visible=False)       
         self._apply         = ControlButton('Apply', checkable=True)
         self._toolbox       = ControlToolBox('Toolbox')
-        self._exportdir     = ControlDir('Export contours to dataset', default='images-from-contours')
+        self._exportdir     = ControlDir('Export images to folder', default='images-from-contour')
         
 
         #### mask ######################################################
@@ -80,11 +80,11 @@ class ContoursImagesWindow(BaseWidget):
         ################################################################
 
         #### rotation ##################################################
-        self._userotup          = ControlCheckBox('Turn the contours always up')
-        self._userotdown        = ControlCheckBox('Turn the contours always down')
+        self._userotup          = ControlCheckBox('Turn the contour always up')
+        self._userotdown        = ControlCheckBox('Turn the contour always down')
         self._usefixedangle     = ControlCheckBox('Use a fixed orientation')
         self._fixedangle        = ControlSlider('Rotate the images using a fixed angle', enabled=True, default=0, minimum=0, maximum=360)
-        self._usedatasetangle   = ControlCheckBox('Use the orientation of other contours')
+        self._usedatasetangle   = ControlCheckBox('Use the orientation of other contour')
         self._datasetanglepanel = ControlEmptyWidget('Datasets for the orientation', enabled=True)
         ################################################################
 
@@ -139,7 +139,7 @@ class ContoursImagesWindow(BaseWidget):
                 (self._usemaskcircular,self._maskcircularsize),
                 (self._usemaskellipse,self._usemaskrect),
             )),
-            ('Margin, image size & stretch image',(
+            ('Margin, image size and stretch image',(
                 self._usestretch,
                 self._margin, 
                 self._imagesize,
@@ -191,7 +191,7 @@ class ContoursImagesWindow(BaseWidget):
 
         events   = {}
         for row in rows:
-            for event in row.periods:
+            for event in row.events:
                 events[event.title] = True
 
         events = sorted(events.keys())
@@ -223,7 +223,7 @@ class ContoursImagesWindow(BaseWidget):
             timeline    = self.mainwindow.timeline
 
             for row in timeline.rows:
-                for event in row.periods:
+                for event in row.events:
                     if event.end<=begin: continue
                     if event.begin>=end: continue
                     if event.title not in selected_events: continue
@@ -278,6 +278,15 @@ class ContoursImagesWindow(BaseWidget):
     def __apply_event(self):
 
         if self._apply.checked:
+
+            if self._usecut.value and self._imagesize.value>0:
+                x, xx = self._cutx.value
+                y, yy = self._cuty.value
+                if int(yy)==int(y) or int(xx)==int(x):
+                    self.message("The second cut value has to be bigger than the first", "Error", "error")
+                    self._apply.checked=False
+                    return
+
             self._toolbox.enabled   = False
             self._exportdir.enabled = False
             self._progress.value    = 0
@@ -296,7 +305,7 @@ class ContoursImagesWindow(BaseWidget):
             ######################################################################
             # create a directory to export the images if the option was selected
             EXPORT_DIRECTORY = self._exportdir.value
-            if len(EXPORT_DIRECTORY)==0: EXPORT_DIRECTORY = 'contours-images'
+            if len(EXPORT_DIRECTORY)==0: EXPORT_DIRECTORY = 'contour-images'
             if not os.path.exists(EXPORT_DIRECTORY): os.makedirs(EXPORT_DIRECTORY)
             ######################################################################
 
@@ -355,7 +364,7 @@ class ContoursImagesWindow(BaseWidget):
                 capture.set(cv2.CAP_PROP_POS_FRAMES, begin); 
                 
                 eventscuts = self.__get_events_cuts(begin, end)
-                exportmap  = self.__get_export_map(begin, end, eventscuts)    
+                exportmap  = self.__get_export_map(begin, end, eventscuts) 
 
                 ######################################################################
                 # create the directories to export the images per video and events
@@ -375,9 +384,14 @@ class ContoursImagesWindow(BaseWidget):
 
                     res, frame = capture.read()
                     #exit in the case the frame was not read.
-                    if not res: return False, None
+                    if not res:
+                        self._apply.label       = 'Apply'
+                        self._toolbox.enabled   = True
+                        self._exportdir.enabled = True
+                        self._apply.checked     = False
+                        self._progress.hide()       
+                        return False, None
 
-                    
                     for foldername in exportmap[i]:
                         if not self._apply.checked: break
                        
@@ -407,12 +421,13 @@ class ContoursImagesWindow(BaseWidget):
                                 imgpath = os.path.join(folder, '{0}.png'.format(i) )
                                 if not os.path.exists(folder): os.makedirs(folder)
 
-                                if self._usecut.value:
+                                if self._usecut.value and self._imagesize.value>0:
                                     x, xx = self._cutx.value
                                     y, yy = self._cuty.value
-                                    img = img[y:yy, x:xx]
+                                    img = img[int(y):int(yy), int(x):int(xx)]
 
                                 cv2.imwrite(imgpath, img)
+
                     self._progress.value += 1
                 
                 
@@ -420,6 +435,7 @@ class ContoursImagesWindow(BaseWidget):
             self._apply.label       = 'Apply'
             self._toolbox.enabled   = True
             self._exportdir.enabled = True
+            self._apply.checked     = False
             self._progress.hide()
 
 
